# == Class: wp_mysql_nfs
#
# Module de déploiement d'une instance CloudStack by Ikoula avec MySQL, NFS et Installation de Wordpress dernière version déportée. A utiliser avec le module wp-apache-nfs pour avoir l'instance web. 
#
# === Parameters
#
# Les paramètres pour ce script se résume au mot de passe root mysql à utiliser qui est demandé à l'utilisateur via le script de déploiement PHP/API en userdata suivant :
# https://raw.github.com/ikoula/cloudstack/master/wp_mysql_nfs.php 
#
# === Authors
#
# Laurent H. Ikoula <contribATikoula.com>
#
# === Copyright
#
# Copyright 2013 Ikoula.
#
class mysql::install {
    package { "mysql-server":
        ensure => present,
        }
    file { "/etc/mysql/my.cnf" :
        replace  => "true",
        source => "/etc/puppet/modules/wp_mysql_nfs/files/etc.mysql.my.cnf",
        owner   => root,
        group   => root,
        require => Package['mysql-server'],
        mode    => 0644
    	}

}
class mysql::passwd {
        exec { 'mysqlpasswd':
                command => 'mysqladmin -u root password `awk \'{print $1}\' /tmp/mysql`',
                path => '/usr/bin',
                require => Class["mysql::install"],
                logoutput => on_failure
        }
}
class mysql::database {
        exec { 'wordpressbdd':
                command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "CREATE DATABASE wordpress;"',
                path => '/usr/bin',
                require => [Class["mysql::install"],
                                Class["mysql::passwd"],
                                ]
        }
}
class mysql::user {
        exec { 'wpuser':
                command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "GRANT USAGE ON *.* to wpuser@\'%\' IDENTIFIED BY \'WordpressWordpress\';" &&  mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "GRANT ALL PRIVILEGES ON wordpress.* to wpuser@\'%\' IDENTIFIED BY \'WordpressWordpress\';" && mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "FLUSH PRIVILEGES;" ; rm -f /tmp/mysql',
                path => ["/usr/bin", "/bin"],
                require => [Class["mysql::passwd"],
                                Class["mysql::database"],
                                ]
        }
}
class mysql::service {
         case $::operatingsystem {
                'CentOS': {
                $mysql_service = 'mysqld'
                }
                'Fedora': {
                $mysql_service = 'mysqld'
                }
                'OpenSuSE': {
                $mysql_service = 'mysql'
                }
                'Debian': {
                $mysql_service = 'mysql'
                }
                'Ubuntu': {
                $mysql_service = 'mysql'
                }
                default: {
                $mysql_service  = 'mysql'
                }
        }
        #On s'assure que le service mysql est en cours d'exécution/activé :
        service { "$mysql_service" :
                        ensure     => running,
                        enable     => true,
                        hasrestart => true,
                        hasstatus => true,
                        require    => Class["mysql::install"],
        }
         exec { 'mysqlrestart':
                command => '/etc/init.d/mysql restart',
        }
}
class nfs::install {
        package { "nfs-kernel-server":
        ensure => present,
        }
        file { "/etc/exports" :
        replace  => "true",
        source => "/etc/puppet/modules/wp_mysql_nfs/files/etc.exports",
        owner   => root,
        group   => root,
        require => Package['nfs-kernel-server'],
        mode    => 0644
        }
        exec { 'tcpwrapper':
                command => '/bin/echo "ALL: *" >> /etc/host.allow',
        }

}
class nfs::service {
        service { "nfs-kernel-server":
        ensure => running,
        enable => true,
        }
        exec { 'nfsservice':
                command => '/etc/init.d/nfs-kernel-server restart',
        }
}
class wp::install {
        package { "unzip":
        ensure => present,
        }
        exec { 'wpdeploy':
                command => 'wget -P /opt http://fr.wordpress.org/wordpress-3.6.1-fr_FR.zip && unzip /opt/wordpress-3.6.1-fr_FR.zip -d /opt && chown -R www-data.www-data /opt/wordpress ; rm -f /opt/wordpress-3.6.1-fr_FR.zip',
                path => ["/usr/bin/", "/bin/", "/sbin/", "/usr/sbin/"],
                require => Package['unzip'],
        }
        file { "/opt/wordpress/wp-config.php" :
                replace  => "true",
                source => "/etc/puppet/modules/wp_mysql_nfs/files/opt.wordpress.wp-config.php",
                owner   => www-data,
                group   => www-data,
                mode    => 0644,
                require => Exec["wpdeploy"],
        }

}
class wp::config {
        exec { 'dbhostip':
                command => 'sed -i "s/dbhostip/"`ifconfig eth0 | grep "inet addr" | cut -f2 -d: | awk \'{print $1}\'`"/g" /opt/wordpress/wp-config.php',
                path => ["/bin/", "/sbin/", "/usr/bin/"],
                require => Class["wp::install"],
        }
}
class wp_mysql_nfs {
       include mysql::install, mysql::passwd, mysql::database, mysql::user, mysql::service, nfs::install, nfs::service, wp::install, wp::config
}
